@@ -3,19 +3,15 @@ import numpy as np
 import torch
 from torchvision.transforms import Compose, Normalize, ToTensor
 
-def preprocess_image(img: np.ndarray, mean=None, std=None) -> torch.Tensor:
-    if std is None:
-        std = [0.5, 0.5, 0.5]
-    if mean is None:
-        mean = [0.5, 0.5, 0.5]
 
+def preprocess_image(img: np.ndarray, mean=[0.5, 0.5, 0.5], std=[0.5, 0.5, 0.5]) -> torch.Tensor:
     preprocessing = Compose([
         ToTensor(),
         Normalize(mean=mean, std=std)
     ])
-
     return preprocessing(img.copy()).unsqueeze(0)
 
+
 def deprocess_image(img):
     """ see https://github.com/jacobgil/keras-grad-cam/blob/master/grad-cam.py#L65 """
     img = img - np.mean(img)
@@ -25,6 +21,7 @@ def deprocess_image(img):
     img = np.clip(img, 0, 1)
     return np.uint8(img * 255)
 
+
 def show_cam_on_image(img: np.ndarray,
                       mask: np.ndarray,
                       use_rgb: bool = False,
@@ -44,7 +41,8 @@ def show_cam_on_image(img: np.ndarray,
     heatmap = np.float32(heatmap) / 255
 
     if np.max(img) > 1:
-        raise Exception("The input image should np.float32 in the range [0, 1]")
+        raise Exception(
+            "The input image should np.float32 in the range [0, 1]")
 
     cam = heatmap + img
     cam = cam / np.max(cam)
